Class: Warren::App::Cli
- Inherits:
-
Thor
- Object
- Thor
- Warren::App::Cli
- Defined in:
- lib/warren/app/cli.rb
Overview
Warren Thor CLI application used to:
- Generate the configuration
- Update the configuration with new consumers
- Start and stop consumers
Class Method Summary collapse
-
.exit_on_failure? ⇒ Boolean
Ensure we exit with an error in the event of failure.
Instance Method Summary collapse
-
#config ⇒ Object
Invoked by
$ warren configgenerates awarren.ymlfile.
Class Method Details
.exit_on_failure? ⇒ Boolean
Ensure we exit with an error in the event of failure
16 17 18 |
# File 'lib/warren/app/cli.rb', line 16 def self.exit_on_failure? true end |