Module: Warren::FrameworkAdaptor
- Defined in:
- lib/warren/framework_adaptor/rails_adaptor.rb
Overview
Namespace for framework adaptors.
A FrameworkAdaptor should implement the following instance methods:
recovered? => Bool
Indicates that any temporary issues (such as database connectivity problems) are resolved and consumers may restart.
handle
Wraps the processing of each message, is expected to yield to allow
processing. May be responsible for handling connection pools, and
framework-specific exceptions. Raising Exceptions::TemporaryIssue
here will cause consumers to sleep until recovered? returns true.
env => String
Returns the current environment of the application.
logger => Logger
Returns your application logger. Is expected to be compatible with the standard library Logger class.
load_application
Called upon running warren consumer start. Should ensure your application
is correctly loaded sufficiently for processing messages
Defined Under Namespace
Classes: RailsAdaptor